@@ -16,15 +16,12 @@
 
 """Decorator helpers that simplify class composition."""
 
-__version__ = '1.0.1'
+import pkg_resources
+__version__ = pkg_resources.resource_string(
+    "lazr.delegates", "version.txt").strip()
 
-# Re-export in such a way that __version__ can still be imported if
-# dependencies are not yet available.
-try:
-    # While we generally frown on "*" imports, this, combined with the fact we
-    # only test code from this module, means that we can verify what has been
-    # exported.
-    from lazr.delegates._delegates import *
-    from lazr.delegates._delegates import __all__
-except ImportError:
-    pass
+# While we generally frown on "*" imports, this, combined with the fact we
+# only test code from this module, means that we can verify what has been
+# exported.
+from lazr.delegates._delegates import *
+from lazr.delegates._delegates import __all__
