@@ -108,19 +108,32 @@ def _delegates_advice(cls):
 
 
 class Passthrough:
-    """Call the delegated class for the decorator class."""
-    def __init__(self, name, contextvar):
+    """Call the delegated class for the decorator class.
+
+    If the ``adaptation`` argument is not None, it should be a callable. It
+    will be called with the context, and should return an object that will
+    have the delegated attribute. The ``adaptation`` argument is expected to
+    be used with an interface, to adapt the context.
+    """
+    def __init__(self, name, contextvar, adaptation=None):
         self.name = name
         self.contextvar = contextvar
+        self.adaptation = adaptation
 
     def __get__(self, inst, cls=None):
         if inst is None:
             return self
         else:
-            return getattr(getattr(inst, self.contextvar), self.name)
+            context = getattr(inst, self.contextvar)
+            if self.adaptation is not None:
+                context = self.adaptation(context)
+            return getattr(context, self.name)
 
     def __set__(self, inst, value):
-        setattr(getattr(inst, self.contextvar), self.name, value)
+        context = getattr(inst, self.contextvar)
+        if self.adaptation is not None:
+            context = self.adaptation(context)
+        setattr(context, self.name, value)
 
     def __delete__(self, inst):
         raise NotImplementedError
